Unreleased changes
------------------

* Remove template artifacts


Version 0
---------

0.4.0 / 2023-09-25
~~~~~~~~~~~~~~~~~~
* Drawing functionality in two classes ``DrawAeff`` and ``DrawEdisp`` 
* ``psf_3d.py`` and ``psf_table.py`` from ``gammapy v0.17`` with modifications
* `Example 2` was filled
* Improved performance of calcutions in ``irf_tools.py``

* Bugs in ``build_irf.py``

  * produced ``.fits`` don't converge with original files from ``/data`` directory


0.3.0 / 2023-02-28
~~~~~~~~~~~~~~~~~~
* Removed calculator
* Docs template is changed to 
  `pydata-sphinx-theme <https://pydata-sphinx-theme.readthedocs.io/en/stable/>`_
* Better documentation for API

0.2.1 / 2022-10-05
~~~~~~~~~~~~~~~~~~
* Fixed minor bugs


0.2.0 / 2022-10-05
~~~~~~~~~~~~~~~~~~
* Added original ``.fits`` files to `src/km3irf/data`
* Increased functionality


0.1.0 / 2022-03-22
~~~~~~~~~~~~~~~~~~
* Project generated using the cookiecutter template from
  https://git.km3net.de/templates/python-project
